@@ -1,9 +1,6 @@
 #!/usr/bin/env python3
 '''__main__.py'''
 
-# Python 2 Compatibility
-from __future__ import print_function, absolute_import
-
 # Internal Libraries
 import os
 import sys
@@ -193,7 +190,7 @@ def main_options(parser):
         help='export as multiple numbered media files.')
 
     parser.add_argument('--temp_dir', default=None,
-        help='set a path to where temporary files are placed.',
+        help='set where the temporary directory is located.',
         extra='If not set, tempdir will be set with Python\'s tempfile module\n'
             'For Windows users, this file will be in the C drive.\n'
             'The temp file can get quite big if you\'re generating a huge video, so '
@@ -609,7 +606,7 @@ def main():
             'loudness and video motion to judge making cuts.\nRun:\n    auto-editor '\
             '--help\n\nTo get the list of options.\n')
 
-    subcommands = ['create', 'test', 'info', 'levels', 'grep', 'subdump']
+    subcommands = ['create', 'test', 'info', 'levels', 'grep', 'subdump', 'desc']
 
     if(len(sys.argv) > 1 and sys.argv[1] in subcommands):
         obj = __import__('auto_editor.subcommands.{}'.format(sys.argv[1]),
@@ -657,7 +654,10 @@ def main():
         TEMP = args.temp_dir
         if(os.path.isfile(TEMP)):
             Log().error('Temp directory cannot be an already existing file.')
-        if(not os.path.isdir(TEMP)):
+        if(os.path.isdir(TEMP)):
+            if(len(os.listdir(TEMP)) != 0):
+                Log().error('Temp directory should be empty!')
+        else:
             os.mkdir(TEMP)
 
     log = Log(args.debug, args.quiet, temp=TEMP)
@@ -735,7 +735,11 @@ def main():
             args.output_file.append(set_output_name(input_list[i], making_data_file, args))
 
     if(args.combine_files):
-        temp_file = os.path.join(TEMP, 'combined.mp4')
+        if(exporting_to_editor):
+            temp_file = 'combined.mp4'
+        else:
+            temp_file = os.path.join(TEMP, 'combined.mp4')
+
         cmd = []
         for fileref in input_list:
             cmd.extend(['-i', fileref])
