@@ -1,5 +1,9 @@
 '''subcommands/create.py'''
 
+import os
+import sys
+import time
+
 def create_options(parser):
     parser.add_argument('--frame_rate', '-fps', '-r', type=float, default=30.0,
         help='set the framerate for the output video.')
@@ -21,11 +25,7 @@ def create_options(parser):
         help='the template')
     return parser
 
-def main(sys_args=None):
-    import os
-    import sys
-    import time
-
+def main(sys_args=sys.argv[1:]):
     import auto_editor
     import auto_editor.vanparse as vanparse
 
@@ -39,8 +39,7 @@ def main(sys_args=None):
     log = Log()
     args = parser.parse_args(sys.argv[2:], Log(), 'create')
 
-    dir_path = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
-    ffmpeg = FFmpeg(dir_path, args.ffmpeg_location, args.my_ffmpeg, False, log)
+    ffmpeg = FFmpeg(args.ffmpeg_location, args.my_ffmpeg, debug=False)
 
     theme = args.input
     output = args.output_file
